@@ -6,6 +6,10 @@ from typing import Optional
 import click
 from vdk.api.plugin.hook_markers import hookspec
 from vdk.api.plugin.plugin_registry import IPluginRegistry
+from vdk.internal.builtin_plugins.run.execution_results import ExecutionResult
+from vdk.internal.builtin_plugins.run.execution_results import StepResult
+from vdk.internal.builtin_plugins.run.job_context import JobContext
+from vdk.internal.builtin_plugins.run.step import Step
 from vdk.internal.core.config import ConfigurationBuilder
 from vdk.internal.core.context import CoreContext
 
@@ -101,7 +105,7 @@ class CoreHookSpecs:
         """
         Called in case the CLI is about to exit with error.
 
-        :return: True if exception is handled and does not need to be logged by main
+        :return: True if exception is handled and does not need to be logged by main, nor affect the exit code
         """
         pass
 
@@ -126,11 +130,6 @@ class JobRunHookSpecs:
     That's because a job template is executed as a normal data job.
     """
 
-    from vdk.internal.builtin_plugins.run.execution_results import ExecutionResult
-    from vdk.internal.builtin_plugins.run.execution_results import StepResult
-    from vdk.internal.builtin_plugins.run.job_context import JobContext
-    from vdk.internal.builtin_plugins.run.step import Step
-
     @hookspec
     def initialize_job(self, context: JobContext) -> None:
         """
@@ -155,12 +154,12 @@ class JobRunHookSpecs:
 
         E.g
         @hookimpl(tryfirst=True)
-        run_job(context): # decorate with logs
+        create_and_run_data_job(context): # decorate with logs
             log.info(f"Start {context.name}"
             # no return
 
         @hookimpl
-        run_job(context): # alternative execution algorithm
+        create_and_run_data_job(context): # alternative execution algorithm
             results = run_in_parallel(steps)
             return results.all_success
 
